@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 use smallnum;
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 our (%TOOL, $ANOBJECT);
 
@@ -412,7 +412,7 @@ Colouring::In - color or colour.
 
 =head1 VERSION
 
-Version 0.26
+Version 0.27
 
 =cut
 
@@ -680,33 +680,24 @@ You can find documentation for this module with the perldoc command.
 
 You can also look for information at:
 
-=over 4
+=over 2
 
 =item * RT: CPAN's request tracker (report bugs here)
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Colouring-In>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Colouring-In>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Colouring-In>
-
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/Colouring-In/>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2017 Robert Acock.
+Copyright 2017->2025 Robert Acock.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
